# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/fa_IR/__init__.py

person_formats_female_fa_ir <- c(
  "{{first_names_female}} {{last_names}}",
  "{{first_names_female}} {{last_names}}",
  "{{first_names_female}} {{last_names}}",
  "{{first_names_female}} {{last_names}}",
  "{{first_names_female}} {{last_names}}",
  "{{prefixes_female}} {{first_names_female}} {{last_names}}"
)

person_formats_male_fa_ir <- c(
  "{{first_names_male}} {{last_names}}",
  "{{first_names_male}} {{last_names}}",
  "{{first_names_male}} {{last_names}}",
  "{{first_names_male}} {{last_names}}",
  "{{first_names_male}} {{last_names}}",
  "{{prefixes_male}} {{first_names_male}} {{last_names}}"
)

person_formats_fa_ir <- c(person_formats_female_fa_ir, person_formats_male_fa_ir)

person_first_names_female_fa_ir <- c(
  "\u0641\u0627\u0637\u0645\u0647",
  "\u0627\u0633\u0645\u0627",
  "\u0632\u0647\u0631\u0627",
  "\u0639\u0633\u0644",
  "\u0646\u0627\u0632\u0646\u06cc\u0646 \u0632\u0647\u0631\u0627",
  "\u0627\u0644\u0646\u0627",
  "\u0632\u06cc\u0646\u0628",
  "\u0633\u0627\u0631\u0627",
  "\u06cc\u0633\u0646\u0627",
  "\u0622\u062a\u0646\u0627",
  "\u0631\u06cc\u062d\u0627\u0646\u0647",
  "\u0622\u06cc\u0646\u0627\u0632",
  "\u0647\u0633\u062a\u06cc",
  "\u0645\u062d\u06cc\u0627",
  "\u0633\u062a\u0627\u06cc\u0634",
  "\u0628\u0627\u0631\u0627\u0646",
  "\u062b\u0646\u0627",
  "\u0647\u0644\u06cc\u0627",
  "\u0645\u0631\u06cc\u0645",
  "\u06cc\u0644\u062f\u0627",
  "\u0641\u0627\u0637\u0645\u0647 \u0632\u0647\u0631\u0627",
  "\u0645\u0644\u06cc\u0643\u0627",
  "\u0633\u0627\u0631\u06cc\u0646\u0627",
  "\u0646\u0627\u0632\u0646\u06cc\u0646",
  "\u0645\u0647\u0633\u0627",
  "\u0622\u06cc\u0644\u06cc\u0646",
  "\u0646\u0631\u06af\u0633",
  "\u062d\u0646\u0627\u0646\u0647",
  "\u0631\u0642\u06cc\u0647",
  "\u0643\u06cc\u0627\u0646\u0627",
  "\u0643\u0648\u062b\u0631",
  "\u0647\u0627\u0646\u06cc\u0647",
  "\u0645\u0628\u06cc\u0646\u0627",
  "\u0645\u0647\u062f\u06cc\u0633",
  "\u0631\u0647\u0627",
  "\u0622\u0648\u0627",
  "\u0627\u0633\u0631\u0627",
  "\u06cc\u06af\u0627\u0646\u0647",
  "\u0646\u06cc\u0627\u06cc\u0634",
  "\u062d\u062f\u06cc\u062b",
  "\u0627\u0644\u06cc\u0646\u0627",
  "\u0633\u0648\u06af\u0646\u062f",
  "\u0645\u0627\u0626\u062f\u0647",
  "\u067e\u0631\u06cc\u0627",
  "\u0645\u0639\u0635\u0648\u0645\u0647",
  "\u0645\u0647\u062f\u06cc\u0647",
  "\u0622\u06cc\u062f\u0627",
  "\u0627\u0644\u0646\u0627\u0632",
  "\u0645\u062d\u062f\u062b\u0647",
  "\u06cc\u0627\u0633\u0645\u06cc\u0646",
  "\u0641\u0627\u0637\u0645\u0647",
  "\u0633\u062a\u0627\u064a\u0634",
  "\u0632\u0647\u0631\u0627",
  "\u0645\u0627\u0626\u062f\u0647",
  "\u0646\u0627\u0632\u0646\u064a\u0646",
  "\u0645\u0628\u064a\u0646\u0627",
  "\u064a\u0633\u0646\u0627",
  "\u0639\u0633\u0644",
  "\u0632\u064a\u0646\u0628",
  "\u0622\u064a\u0646\u0627\u0632",
  "\u0631\u064a\u062d\u0627\u0646\u0647",
  "\u0647\u0644\u064a\u0627",
  "\u0641\u0627\u0637\u0645\u0647",
  "\u0633\u0648\u06af\u0646\u062f",
  "\u0628\u0627\u0631\u0627\u0646",
  "\u0633\u0627\u0631\u0627",
  "\u0631\u0647\u0627",
  "\u0645\u062d\u062f\u062b\u0647",
  "\u062b\u0646\u0627",
  "\u0627\u0644\u064a\u0646\u0627",
  "\u06a9\u0648\u062b\u0631",
  "\u0622\u062a\u0646\u0627",
  "\u0645\u0631\u064a\u0645",
  "\u0641\u0627\u0637\u0645\u064a\u0627",
  "\u0633\u0627\u0631\u064a\u0646\u0627",
  "\u064a\u0627\u0633\u0645\u064a\u0646",
  "\u0627\u0633\u0631\u0627",
  "\u062d\u0633\u0646\u0627",
  "\u0631\u0642\u064a\u0647",
  "\u0627\u0633\u0645\u0627",
  "\u0647\u0633\u062a\u064a",
  "\u0645\u0647\u062f\u064a\u0633",
  "\u0645\u062d\u064a\u0627",
  "\u0647\u0627\u0646\u064a\u0647",
  "\u0622\u064a\u0644\u064a\u0646",
  "\u062d\u0646\u0627\u0646\u0647",
  "\u0645\u0647\u0633\u0627",
  "\u067e\u0631\u0646\u064a\u0627",
  "\u0646\u0631\u06af\u0633",
  "\u0622\u064a\u062f\u0627",
  "\u0645\u0639\u0635\u0648\u0645\u0647",
  "\u06a9\u064a\u0627\u0646\u0627",
  "\u062d\u0644\u0645\u0627",
  "\u0645\u0644\u064a\u06a9\u0627",
  "\u0622\u0648\u0627",
  "\u0646\u0627\u0632\u0646\u064a\u0646",
  "\u0627\u0644\u0646\u0627",
  "\u0627\u0644\u0646\u0627\u0632",
  "\u0646\u064a\u0627\u064a\u0634",
  "\u0628\u0647\u0627\u0631"
)

person_first_names_male_fa_ir <- c(
  "\u0627\u0645\u06cc\u0631 \u0639\u0644\u06cc",
  "\u067e\u0631\u0647\u0627\u0645",
  "\u0627\u0628\u0648\u0627\u0644\u0641\u0636\u0644",
  "\u0643\u06cc\u0627\u0646",
  "\u0627\u0645\u06cc\u0631\u062d\u0633\u06cc\u0646",
  "\u0645\u062a\u06cc\u0646",
  "\u0645\u062d\u0645\u062f \u0637\u0627\u0647\u0627",
  "\u0639\u0631\u0641\u0627\u0646",
  "\u0645\u062d\u0645\u062f",
  "\u062f\u0627\u0646\u06cc\u0627\u0644",
  "\u0639\u0644\u06cc",
  "\u0622\u0631\u0645\u06cc\u0646",
  "\u0627\u0645\u06cc\u0631\u0645\u062d\u0645\u062f",
  "\u0622\u0631\u062a\u06cc\u0646",
  "\u062d\u0633\u06cc\u0646",
  "\u0633\u0628\u062d\u0627\u0646",
  "\u0645\u0647\u062f\u06cc",
  "\u0633\u06cc\u0646\u0627",
  "\u0645\u062d\u0645\u062f \u0645\u0647\u062f\u06cc",
  "\u0622\u0631\u06cc\u0627",
  "\u0645\u062d\u0645\u062f\u0631\u0636\u0627",
  "\u0645\u062d\u0645\u062f\u067e\u0627\u0631\u0633\u0627",
  "\u0637\u0627\u0647\u0627",
  "\u0633\u062c\u0627\u062f",
  "\u0627\u0645\u06cc\u0631\u0631\u0636\u0627",
  "\u0622\u0631\u0634",
  "\u0627\u0645\u06cc\u0631\u0639\u0628\u0627\u0633",
  "\u0646\u06cc\u0645\u0627",
  "\u0639\u0644\u06cc\u0631\u0636\u0627",
  "\u0639\u0631\u0634\u06cc\u0627",
  "\u0645\u062d\u0645\u062f\u0627\u0645\u06cc\u0646",
  "\u0645\u0628\u06cc\u0646",
  "\u0645\u062d\u0645\u062f\u062d\u0633\u06cc\u0646",
  "\u06cc\u0648\u0633\u0641",
  "\u0631\u0636\u0627",
  "\u0627\u062d\u0633\u0627\u0646",
  "\u0639\u0644\u06cc \u0627\u0635\u063a\u0631",
  "\u0622\u0631\u06cc\u0646",
  "\u0627\u0645\u06cc\u0631\u0645\u0647\u062f\u06cc",
  "\u0645\u062d\u0645\u062f\u06cc\u0627\u0633\u06cc\u0646",
  "\u0645\u0627\u0647\u0627\u0646",
  "\u0639\u0628\u0627\u0633",
  "\u067e\u0627\u0631\u0633\u0627",
  "\u062d\u0633\u0627\u0645",
  "\u06cc\u0627\u0633\u06cc\u0646",
  "\u0639\u0644\u06cc \u0631\u0636\u0627",
  "\u0627\u06cc\u0644\u06cc\u0627",
  "\u0639\u0644\u06cc \u0627\u0643\u0628\u0631",
  "\u0645\u062d\u0645\u062f\u062c\u0648\u0627\u062f",
  "\u0628\u0646\u06cc\u0627\u0645\u06cc\u0646",
  "\u0627\u0645\u064a\u0631\u0639\u0644\u064a",
  "\u0627\u064a\u0644\u064a\u0627",
  "\u0645\u062d\u0645\u062f",
  "\u0645\u062d\u0645\u062f\u067e\u0627\u0631\u0633\u0627",
  "\u0645\u062d\u0645\u062f",
  "\u067e\u0631\u0647\u0627\u0645",
  "\u0627\u0628\u0648\u0627\u0644\u0641\u0636\u0644",
  "\u0633\u0628\u062d\u0627\u0646",
  "\u0627\u0645\u064a\u0631\u062d\u0633\u064a\u0646",
  "\u0622\u0631\u062a\u064a\u0646",
  "\u0639\u0644\u064a",
  "\u0622\u0631\u0645\u064a\u0646",
  "\u062d\u0633\u064a\u0646",
  "\u0639\u0631\u0641\u0627\u0646",
  "\u0627\u0645\u064a\u0631\u0645\u062d\u0645\u062f",
  "\u0622\u0631\u064a\u0627",
  "\u0627\u0645\u064a\u0631\u0639\u0628\u0627\u0633",
  "\u0645\u062d\u0645\u062f\u064a\u0627\u0633\u064a\u0646",
  "\u0645\u062d\u0645\u062f\u0645\u0647\u062f\u064a",
  "\u0645\u062a\u064a\u0646",
  "\u0645\u062d\u0645\u062f\u0631\u0636\u0627",
  "\u062f\u0627\u0646\u064a\u0627\u0644",
  "\u0645\u0647\u062f\u064a",
  "\u0633\u0627\u0645\u064a\u0627\u0631",
  "\u0645\u062d\u0645\u062f\u062d\u0633\u064a\u0646",
  "\u0627\u062d\u0633\u0627\u0646",
  "\u0627\u0645\u064a\u0631\u0631\u0636\u0627",
  "\u0622\u0631\u064a\u0646",
  "\u0639\u0644\u064a\u0631\u0636\u0627",
  "\u0633\u064a\u0646\u0627",
  "\u0645\u062d\u0645\u062f\u0627\u0645\u064a\u0646",
  "\u0622\u0631\u0627\u062f",
  "\u0639\u0644\u064a",
  "\u0633\u062c\u0627\u062f",
  "\u0637\u0627\u0647\u0627",
  "\u062d\u0633\u0627\u0645",
  "\u0631\u0636\u0627",
  "\u064a\u0648\u0633\u0641",
  "\u0645\u0627\u0647\u0627\u0646",
  "\u0622\u0631\u0634",
  "\u0645\u0628\u064a\u0646",
  "\u064a\u0627\u0633\u064a\u0646",
  "\u0639\u0644\u064a",
  "\u0627\u0645\u064a\u0631\u0645\u0647\u062f\u064a",
  "\u0639\u0628\u0627\u0633",
  "\u067e\u0627\u0631\u0633\u0627",
  "\u0645\u062d\u0645\u062f\u0639\u0644\u064a",
  "\u06a9\u064a\u0627\u0646",
  "\u0645\u062d\u0645\u062f\u062c\u0648\u0627\u062f",
  "\u0628\u0646\u064a\u0627\u0645\u064a\u0646"
)

person_first_names_fa_ir <- c(person_first_names_female_fa_ir, person_first_names_male_fa_ir)

person_last_names_fa_ir <- c(
  "\u0645\u062d\u0645\u062f\u06cc",
  "\u0645\u062d\u0645\u062f \u067e\u0648\u0631",
  "\u0627\u06a9\u0628\u0631 \u067e\u0648\u0631",
  "\u0631\u0636\u0627 \u0632\u0627\u062f\u0647",
  "\u0645\u062c\u062a\u0647\u062f\u06cc",
  "\u062f\u0627\u06cc\u06cc",
  "\u062d\u0645\u06cc\u062f\u06cc",
  "\u06a9\u0627\u0628\u0644\u06cc",
  "\u0639\u0628\u062f\u0627\u0644\u0639\u0644\u06cc",
  "\u0627\u062d\u0645\u062f\u06cc",
  "\u0627\u0634\u0631\u0641\u06cc",
  "\u0639\u0644\u06cc\u062c\u0627\u0646\u06cc",
  "\u0627\u0628\u0648\u0637\u0627\u0644\u0628\u06cc",
  "\u0639\u0644\u06cc \u0634\u0627\u0647\u06cc",
  "\u0627\u0644\u0648\u0646\u062f\u06cc",
  "\u0628\u0647\u0645\u0646\u06cc",
  "\u0628\u0647\u0631\u0627\u0645\u06cc",
  "\u0647\u0646\u0631\u06cc",
  "\u0627\u06cc\u0631\u0648\u0627\u0646\u06cc",
  "\u062d\u0631\u06cc\u0631\u06cc\u0627\u0646",
  "\u062c\u0639\u0641\u0631 \u067e\u0648\u0631",
  "\u062c\u0644\u0627\u0644\u06cc",
  "\u062c\u0644\u06cc\u0644\u06cc",
  "\u0631\u0648\u062d\u0627\u0646\u06cc",
  "\u062e\u0633\u0631\u0648\u062c\u0631\u062f\u06cc",
  "\u0645\u0646\u0635\u0648\u0631\u06cc",
  "\u0645\u0647\u062f\u06cc\u0627\u0646",
  "\u0646\u0648\u0631\u0648\u0632\u06cc",
  "\u0646\u0648\u0631\u06cc",
  "\u0631\u0633\u062a\u0647",
  "\u0633\u0645\u0627\u0648\u0627\u062a",
  "\u0633\u0645\u0633\u0627\u0631",
  "\u0634\u0627\u062f\u0631\u0648\u0627\u0646",
  "\u0634\u0627\u06a9\u0631\u06cc",
  "\u0633\u0644\u0637\u0627\u0646\u06cc",
  "\u0634\u0628\u06cc\u0631\u06cc",
  "\u062a\u062d\u0633\u06cc\u0646\u06cc",
  "\u062a\u0646\u0632\u06cc\u0644\u06cc",
  "\u0637\u0644\u0648\u0639\u06cc",
  "\u0648\u0644\u0627\u0634\u062c\u0631\u062f\u06cc",
  "\u0648\u062b\u0627\u0642",
  "\u0638\u0641\u0631\u06cc",
  "\u0632\u0645\u0627\u0646\u06cc",
  "\u0632\u0627\u0631\u0639",
  "\u0632\u0627\u0631\u0639\u06cc",
  "\u0631\u0628\u0627\u0646\u06cc",
  "\u0634\u0645\u0634\u06cc\u0631\u06cc",
  "\u0635\u0627\u0631\u0645\u06cc",
  "\u0635\u06cc\u0627\u062f\u06cc",
  "\u0633\u0631\u062e\u0648\u0634\u06cc\u0627\u0646",
  "\u0631\u0633\u062a\u0645\u06cc",
  "\u0631\u0633\u0648\u0644\u06cc",
  "\u0631\u0641\u06cc\u0639\u06cc",
  "\u06a9\u0631\u06cc\u0645\u06cc",
  "\u06a9\u0631\u0645\u0627\u0646\u06cc",
  "\u0633\u0639\u06cc\u062f\u06cc",
  "\u0639\u0628\u0627\u0633\u06cc",
  "\u067e\u0648\u06cc\u0627\u0646",
  "\u062a\u0631\u06a9\u0627\u0634\u0648\u0646\u062f",
  "\u0632\u0646\u062c\u0627\u0646\u06cc",
  "\u062a\u0647\u0631\u0627\u0646\u06cc",
  "\u062c\u0646\u062a\u06cc",
  "\u0635\u0646\u0627\u06cc\u0639\u06cc",
  "\u062c\u0647\u0627\u0646\u06cc",
  "\u0627\u0634\u062a\u0631\u06cc",
  "\u0686\u0646\u06af\u06cc\u0632\u06cc",
  "\u062f\u0627\u062f\u0641\u0631",
  "\u0633\u063a\u06cc\u0631\u06cc",
  "\u067e\u0627\u0631\u0633\u0627",
  "\u0636\u0627\u0628\u0637\u06cc",
  "\u0645\u06cc\u0631\u062f\u0627\u0645\u0627\u062f\u06cc",
  "\u0639\u0642\u06cc\u0644\u06cc",
  "\u0646\u0627\u0645\u0648\u0631",
  "\u062d\u0633\u0646\u06cc",
  "\u0644\u0627\u0647\u0648\u062a\u06cc",
  "\u0645\u062d\u062c\u0648\u0628",
  "\u0647\u0627\u0634\u0645\u06cc",
  "\u0645\u0639\u0631\u0648\u0641",
  "\u0645\u0639\u06cc\u0646",
  "\u0647\u0648\u0634\u06cc\u0627\u0631",
  "\u0647\u0648\u0645\u0646",
  "\u0647\u062f\u0627\u06cc\u062a",
  "\u0642\u0627\u0636\u06cc",
  "\u0645\u0644\u06a9\u06cc\u0627\u0646",
  "\u0636\u0631\u063a\u0627\u0645\u06cc",
  "\u06cc\u0632\u062f\u06cc",
  "\u0646\u0648\u0628\u062e\u062a\u06cc",
  "\u0645\u062c\u062a\u0628\u0648\u06cc",
  "\u0646\u06cc\u0644\u0648\u0641\u0631\u06cc",
  "\u0644\u0627\u0686\u06cc\u0646\u06cc",
  "\u0639\u0644\u06cc \u067e\u0648\u0631",
  "\u0639\u0628\u062f\u0627\u0644\u0645\u0627\u0644\u06a9\u06cc",
  "\u0641\u0631\u062c\u06cc",
  "\u0645\u0648\u0633\u0648\u06cc",
  "\u0647\u0645\u062f\u0627\u0646\u06cc",
  "\u0645\u0648\u062d\u062f",
  "\u06a9\u0645\u0627\u0644\u06cc",
  "\u06af\u0644\u067e\u0627\u06cc\u06af\u0627\u0646\u06cc",
  "\u0646\u0639\u0645\u062a\u06cc",
  "\u0639\u0632\u06cc\u0632\u06cc",
  "\u0631\u0648\u062f\u06af\u0631"
)

person_prefixes_male_fa_ir <- c(
  "\u062c\u0646\u0627\u0628 \u0622\u0642\u0627\u06cc",
  "\u062c\u0646\u0627\u0628 \u0622\u0642\u0627\u06cc \u062f\u06a9\u062a\u0631"
)

person_prefixes_female_fa_ir <- c(
  "\u0633\u0631\u06a9\u0627\u0631 \u062e\u0627\u0646\u0645",
  "\u0633\u0631\u06a9\u0627\u0631 \u062e\u0627\u0646\u0645 \u062f\u06a9\u062a\u0631"
)

person_fa_ir <- list(
  first_names = person_first_names_fa_ir,
  first_names_male = person_first_names_male_fa_ir,
  first_names_female = person_first_names_female_fa_ir,
  last_names = person_last_names_fa_ir,
  prefixes_female = person_prefixes_female_fa_ir,
  prefixes_male = person_prefixes_male_fa_ir
)

#' @title Person Provider for Farsi (Iran)
#' @inherit PersonProvider description details return
#' @export
#' @family fa
#' @family IR
#' @details Note for female and male components that we fall back on generic
#' versions if the locale
#' doesn't provide a male/female version.
#' e.g., if no female first name we use first
#' name
#' @examples
#' x <- PersonProvider_fa_IR$new()
#' x$locale
#' x$render()
#' x$first_name()
#' x$first_name_female()
#' x$first_name_male()
#' x$last_name()
#' x$last_name_female()
#' x$last_name_male()
PersonProvider_fa_IR <- R6::R6Class(
  "PersonProvider_fa_IR",
  inherit = PersonProvider,
  private = list(
    # person name formats
    formats = person_formats_fa_ir,
    # person name data
    persons = person_fa_ir,
    locale_ = "fa_IR"
  )
)
